otcextensions.sdk.cbr.v3.checkpoint
===================================

.. automodule:: otcextensions.sdk.cbr.v3.checkpoint

The CBR Checkpoint Class
------------------------

The ``Checkpoint`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.Checkpoint
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.Parameters
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.ResourceDetails
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.ResourceExtraInfo
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.IncludeVolumes
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.Vault
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.SkippedResource
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.CheckpointResource
   :members:

.. autoclass:: otcextensions.sdk.cbr.v3.checkpoint.ExtraInfo
   :members:
